@@ -47,6 +47,7 @@ def parse(page, domain=''):
         'postalCode': '',
         'addressLine': '',
         'meta': '',
+        'metakeywords': '',
         'innerLinks':'',
         'homepageText':'',
         'contactText': '',
@@ -59,6 +60,9 @@ def parse(page, domain=''):
     meta = soup.findAll('meta', {"name": "description", "content": True})
     if meta:
         result['meta'] = meta[0]['content']
+    metakeywords = soup.findAll('meta', {"name": "keywords", "content": True})
+    if meta:
+        result['metakeywords'] = metakeywords[0]['content']
 
     addresses = pyap.parse(vis, country='CA')
     addresses += pyap.parse(vis, country='US')
